@@ -19,8 +19,8 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -28,27 +28,13 @@
 #define _Hgn1_huginConfig_H
 
 #include <hugin_shared.h>
+#include <panodata/Panorama.h>
 #include <panoinc_WX.h>
 
-#include "PT/Panorama.h"
-#include <algorithms/panorama_makefile/PanoramaMakefilelibExport.h>
-#include <algorithms/assistant_makefile/AssistantMakefilelibExport.h>
-
-namespace PT {
-struct PTPrograms : public HuginBase::PanoramaMakefilelibExport::PTPrograms {};
-struct AssistantPrograms : public HuginBase::AssistantMakefilelibExport::AssistantPrograms {};
-}
-
-WXIMPEX PT::PTPrograms getPTProgramsConfig(wxString huginRoot, wxConfigBase * config);
-WXIMPEX PT::AssistantPrograms getAssistantProgramsConfig(wxString huginRoot, wxConfigBase * config);
-
-/** get the path to the directory where the currently running executable is
- *  stored.
- *
- *  Should work well on Windows, might work on OSX and does not work on
- *  Unix.
- *
- */
-WXIMPEX wxString getExePath(wxString argv0);
+/** gets the default project name, as defined in the preferences */
+WXIMPEX wxString getDefaultProjectName(const HuginBase::Panorama & pano, const wxString filenameTemplate=wxT(""));
+/** gets the default output prefix, based on filename and images in project
+  * the setting is read from the preferences */
+WXIMPEX wxString getDefaultOutputName(const wxString projectname, const HuginBase::Panorama & pano, const wxString filenameTemplate=wxT(""));
 
 #endif
