@@ -45,8 +45,8 @@ bool CalculateOptimalROI::calcOptimalROI(PanoramaData& panorama)
     m_bestRect = vigra::Rect2D();
     try
     {
-        testedPixels.resize(o_optimalSize.x*o_optimalSize.y,false);
-        pixels.resize(o_optimalSize.x*o_optimalSize.y,false);
+        testedPixels.resize(static_cast<long long>(o_optimalSize.x) * o_optimalSize.y,false);
+        pixels.resize(static_cast<long long>(o_optimalSize.x) * o_optimalSize.y,false);
     }
     catch(std::bad_alloc&)
     {
@@ -119,7 +119,7 @@ bool CalculateOptimalROI::stackPixel(int i, int j, UIntSet &stack)
 
 bool CalculateOptimalROI::imgPixel(int i, int j)
 {
-    if(!testedPixels[j*o_optimalSize.x+i])
+    if(!testedPixels[static_cast<long long>(j) * o_optimalSize.x + i])
     {
         bool inside;
         
@@ -143,15 +143,15 @@ bool CalculateOptimalROI::imgPixel(int i, int j)
             }
         }
 
-        testedPixels[j*o_optimalSize.x + i] = true;
-        pixels[j*o_optimalSize.x + i] = inside;
+        testedPixels[static_cast<long long>(j) * o_optimalSize.x + i] = true;
+        pixels[static_cast<long long>(j) * o_optimalSize.x + i] = inside;
         
         return inside;
     }
     //else it is know if this pixel is covered by at least one image
     else
     {
-        return pixels[j*o_optimalSize.x+i];
+        return pixels[static_cast<long long>(j) * o_optimalSize.x + i];
     }
 }
 
@@ -182,7 +182,7 @@ void CalculateOptimalROI::AddCheckingRects(std::list<vigra::Rect2D>& testingRect
 /** check if given rect covers the whole pano */
 bool CalculateOptimalROI::CheckRectCoversPano(const vigra::Rect2D& rect)
 {
-    for (size_t i = rect.left(); i<rect.right(); i++)
+    for (int i = rect.left(); i<rect.right(); i++)
     {
         if (imgPixel(i, rect.top()) == 0 || imgPixel(i, rect.bottom() - 1) == 0)
         {
@@ -190,7 +190,7 @@ bool CalculateOptimalROI::CheckRectCoversPano(const vigra::Rect2D& rect)
         }
     }
 
-    for (size_t j = rect.top(); j<rect.bottom(); j++)
+    for (int j = rect.top(); j<rect.bottom(); j++)
     {
         if (imgPixel(rect.left(), j) == 0 || imgPixel(rect.right() - 1, j) == 0)
         {
