@@ -101,15 +101,21 @@ std::string getKeyfilenameFor(std::string keyfilesPath, std::string filename)
 PanoDetector::PanoDetector() :
     _writeAllKeyPoints(false), _verbose(1),
     _sieve1Width(10), _sieve1Height(10), _sieve1Size(100),
-    _kdTreeSearchSteps(200), _kdTreeSecondDistance(0.25), _ransacIters(1000), _ransacDistanceThres(50),
-    _sieve2Width(5), _sieve2Height(5), _sieve2Size(1), _test(false), _cores(0), svmModel(NULL),
-    _minimumMatches(6), _linearMatchLen(1), _downscale(true), _cache(false), _cleanup(false),
-    _keypath(""), _outputFile("default.pto"), _outputGiven(false), _celeste(false), _celesteThreshold(0.5), _celesteRadius(20), 
-    _matchingStrategy(ALLPAIRS), _ransacMode(HuginBase::RANSACOptimizer::AUTO)
+    _kdTreeSearchSteps(200), _kdTreeSecondDistance(0.25),
+    _minimumMatches(6), _ransacMode(HuginBase::RANSACOptimizer::AUTO), _ransacIters(1000), _ransacDistanceThres(50),
+    _sieve2Width(5), _sieve2Height(5), _sieve2Size(1),
+    _matchingStrategy(ALLPAIRS), _linearMatchLen(1),
+    _test(false), _cores(0), _downscale(true), _cache(false), _cleanup(false),
+    _celeste(false), _celesteThreshold(0.5), _celesteRadius(20), 
+    _keypath(""), _outputFile("default.pto"), _outputGiven(false), svmModel(NULL)
 {
     _panoramaInfo = new HuginBase::Panorama();
 }
 
+PanoDetector::~PanoDetector()
+{
+    delete _panoramaInfo;
+}
 
 bool PanoDetector::checkData()
 {
@@ -155,7 +161,7 @@ void PanoDetector::printDetails()
             std::cout << "Output file          : " << _outputFile << std::endl;
         };
     }
-    if(_keypath.size()>0)
+    if(!_keypath.empty())
     {
         std::cout <<     "Path to keyfiles     : " << _keypath << std::endl;
     };
@@ -245,7 +251,7 @@ void PanoDetector::printFilenames()
         }
         std::cout << "Image " << i << std::endl << "  Imagefile: " << name << std::endl;
         bool writeKeyfileForImage=false;
-        if(_keyPointsIdx.size()>0)
+        if(!_keyPointsIdx.empty())
         {
             for(unsigned j=0; j<_keyPointsIdx.size() && !writeKeyfileForImage; j++)
             {
@@ -269,7 +275,7 @@ void PanoDetector::printFilenames()
                 std::cout << (_filesData[i]._hasakeyfile?" (will be loaded)":" (will be generated)") << std::endl;
             };
         };
-        std::cout << "  Remapped : " << (_filesData[i]._needsremap?"yes":"no") << std::endl;
+        std::cout << "  Remapped : " << (_filesData[i].NeedsRemapping()?"yes":"no") << std::endl;
     };
 };
 
@@ -278,6 +284,7 @@ class Runnable
 public:
     Runnable() {};
     virtual void run() = 0;
+    virtual ~Runnable() {};
 };
 
 // definition of a runnable class for image data
@@ -285,7 +292,7 @@ class ImgDataRunnable : public Runnable
 {
 public:
     ImgDataRunnable(PanoDetector::ImgData& iImageData, const PanoDetector& iPanoDetector) : Runnable(),
-        _imgData(iImageData), _panoDetector(iPanoDetector) {};
+        _panoDetector(iPanoDetector), _imgData(iImageData) {};
 
     virtual void run()
     {
@@ -311,7 +318,7 @@ class WriteKeyPointsRunnable : public Runnable
 {
 public:
     WriteKeyPointsRunnable(PanoDetector::ImgData& iImageData, const PanoDetector& iPanoDetector) :
-        _imgData(iImageData), _panoDetector(iPanoDetector) {};
+        _panoDetector(iPanoDetector), _imgData(iImageData) {};
 
     virtual void run()
     {
@@ -336,7 +343,7 @@ class LoadKeypointsDataRunnable : public Runnable
 {
 public:
     LoadKeypointsDataRunnable(PanoDetector::ImgData& iImageData, const PanoDetector& iPanoDetector) :
-        _imgData(iImageData), _panoDetector(iPanoDetector) {};
+        _panoDetector(iPanoDetector), _imgData(iImageData) {};
 
     virtual void run()
     {
@@ -355,12 +362,12 @@ class MatchDataRunnable : public Runnable
 {
 public:
     MatchDataRunnable(PanoDetector::MatchData& iMatchData, const PanoDetector& iPanoDetector) :
-        _matchData(iMatchData), _panoDetector(iPanoDetector) {};
+        _panoDetector(iPanoDetector), _matchData(iMatchData) {};
 
     virtual void run()
     {
         //TRACE_PAIR("Matching...");
-        if(_matchData._i1->_kp.size()>0 && _matchData._i2->_kp.size()>0)
+        if(!_matchData._i1->_kp.empty() && !_matchData._i2->_kp.empty())
         {
             PanoDetector::FindMatchesInPair(_matchData, _panoDetector);
             PanoDetector::RansacMatchesInPair(_matchData, _panoDetector);
@@ -447,13 +454,17 @@ void PanoDetector::run()
         if(!aB->second._hasakeyfile)
         {
             maxImageSize=std::max<unsigned long>(aB->second._detectWidth*aB->second._detectHeight,maxImageSize);
-            if(aB->second._needsremap)
+            if(aB->second.NeedsRemapping())
             {
                 withRemap=true;
             };
         };
     };
 #ifdef HAVE_OPENMP
+    if (_cores == 0)
+    {
+        setCores(omp_get_max_threads());
+    };
     if (maxImageSize != 0)
     {
         unsigned long long maxCores;
@@ -472,10 +483,6 @@ void PanoDetector::run()
         {
             maxCores=1;
         }
-        if (_cores == 0)
-        {
-            setCores(omp_get_max_threads());
-        }
         if(maxCores<_cores)
         {
             if(getVerbose()>0)
@@ -591,7 +598,7 @@ void PanoDetector::run()
     };
 
     // Detect matches if writeKeyPoints wasn't set
-    if(_keyPointsIdx.size() == 0)
+    if(_keyPointsIdx.empty())
     {
         switch (getMatchingStrategy())
         {
@@ -764,6 +771,14 @@ bool PanoDetector::loadProject()
     // image options
     _panoramaInfoCopy=_panoramaInfo->duplicate();
 
+    // create a hash set for all known control points
+    {
+        const HuginBase::CPVector& allCps = _panoramaInfo->getCtrlPoints();
+        for (auto& cp : allCps)
+        {
+            _cpsHashSet.insert(cp.getCPString());
+        };
+    }
     // Add images found in the project file to _filesData
     const unsigned int nImg = _panoramaInfo->getNrOfImages();
     unsigned int imgWithKeyfile=0;
@@ -794,12 +809,13 @@ bool PanoDetector::loadProject()
         // Number pointing to image info in _panoramaInfo
         aImgData._number = imgNr;
 
-        aImgData._needsremap=(img.getHFOV()>=65 && img.getProjection() != HuginBase::SrcPanoImage::FISHEYE_STEREOGRAPHIC);
+        bool needsremap=(img.getHFOV()>=65 && img.getProjection() != HuginBase::SrcPanoImage::FISHEYE_STEREOGRAPHIC);
         // set image detection size
-        if(aImgData._needsremap)
+        if(needsremap)
         {
             _filesData[imgNr]._detectWidth = std::max(img.getSize().width(),img.getSize().height());
             _filesData[imgNr]._detectHeight = std::max(img.getSize().width(),img.getSize().height());
+            _filesData[imgNr].SetSizeMode(ImgData::REMAPPED);
         }
         else
         {
@@ -807,14 +823,19 @@ bool PanoDetector::loadProject()
             _filesData[imgNr]._detectHeight = img.getSize().height();
         };
 
-        if (_downscale)
+        // don't downscale if downscale image is smaller than 1000 pixel
+        if (_downscale && std::min(img.getSize().width(), img.getSize().height()) > 2000)
         {
             _filesData[imgNr]._detectWidth >>= 1;
             _filesData[imgNr]._detectHeight >>= 1;
+            if (!_filesData[imgNr].NeedsRemapping())
+            {
+                _filesData[imgNr].SetSizeMode(ImgData::DOWNSCALED);
+            };
         }
 
         // set image remapping options
-        if(aImgData._needsremap)
+        if (aImgData.GetSizeMode() == ImgData::REMAPPED)
         {
             aImgData._projOpts.setProjection(HuginBase::PanoramaOptions::STEREOGRAPHIC);
             aImgData._projOpts.setHFOV(250);
@@ -1174,7 +1195,7 @@ bool PanoDetector::matchPrealigned(HuginBase::Panorama* pano, std::vector<HuginB
         HuginBase::VariableMapVector varMapVec = tempPano.getVariables();
         for(size_t i=0; i<tempPano.getNrOfImages(); i++)
         {
-            HuginBase::Variable hfovVar = map_get(varMapVec[i], "v");
+            HuginBase::Variable& hfovVar = map_get(varMapVec[i], "v");
             hfovVar.setValue(std::min(360.0, 1.25 * hfovVar.getValue()));
         };
         tempPano.updateVariables(varMapVec);
